<?php declare(strict_types=1);

namespace App\Console\Commands\Files;

use App\Services\Commands\DeleteOldFilesService;
use Illuminate\Console\Command;
use Illuminate\Support\Carbon;

final class DeleteOldFilesFromStorage extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'files:delete-old-files-from-storage';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Remove temporary files or files that have been deleted from the storage table';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     */
    public function handle(DeleteOldFilesService $deleteOldFilesService): void
    {
        $temporaryBeforeDate = Carbon::now()->subDays(3);
        $deletedBeforeDate   = Carbon::now()->subDays(7);

        $result = $deleteOldFilesService->fromStorage($temporaryBeforeDate, $deletedBeforeDate);
        if ($result->isError()) {
            $this->error($result->getMessage());
            return;
        }
        $this->info($result->getMessage());
    }
}
