<?php declare(strict_types=1);

namespace App\Dto\Service\Admin\Project\Translation;

use App\Enums\DocumentationVersionStatus;
use App\Exceptions\Dto\Admin\Project\Transaction\TranslationsException;

final class Translations
{
    private array $translations = [];

    public function addTranslation(string $code, ?string $text): void
    {
        if (!in_array($code, self::getTranslationCodes())) {
            throw new TranslationsException('Translation code "' . $code . '" not available');
        }
        $this->translations[] = new Translation($code, $text);
    }

    public function getTranslations(): array
    {
        return $this->translations;
    }

    public static function getTranslationCodes(): array
    {
        $translations = [
            'site.Menu',
            'site.Powered by service',
            'site.About project',
            'site.Choose language',
            'site.Page without translation',
            'site.Project',
            'site.Feedback',
            'site.Feedback-send',
            'site.required field',
            'site.attributes.name',
            'site.attributes.email',
            'site.attributes.message',
            'site.Message sent successfully',
            'Server Error',
            'site.Documentation',
            'site.Documentation not created',
            'site.Choose version',
            'site.alert-status-not-supported',
            'site.alert-status-future',
        ];

        foreach (DocumentationVersionStatus::cases() as $status) {
            $translations[] = $status->getCodeForTranslation();
        }

        return $translations;
    }
}
