<?php declare(strict_types=1);

namespace App\Dto\Service\Storage;

use App\Dto\Service\Dto;
use App\Enums\StorageType;
use app\Exceptions\Dto\Storage\StorageException;

final readonly class Storage extends Dto
{
    private ?File $file;
    private bool $isDelete;

    public function __construct(
        array $data,
        private StorageType $storageType,
        private bool $isMany,
    ) {
        $file = null;
        if (isset($data['file'])) {
            if ((int) $data['file'] <= 0) {
                throw new StorageException('ID cannot be equal to or less than zero: ' . $data['file']);
            }
            $file = new File(
                id: (int) $data['file'],
                storageType: $this->storageType,
            );
        }
        $this->file = $file;
        $this->isDelete = !empty($data['delete']);
    }

    public function getFile(): ?File
    {
        return $this->file;
    }

    public function isDelete(): bool
    {
        return $this->isDelete;
    }

    public function isFile(): bool
    {
        return \is_null($this->file) === false;
    }

    public function getStorageType(): StorageType
    {
        return $this->storageType;
    }

    public function isMany(): bool
    {
        return $this->isMany;
    }
}
