<?php declare(strict_types=1);

namespace App\Dto\Service\Storage;

use App\Enums\StorageType;
use app\Exceptions\Dto\Storage\StoragesException;

final class Storages
{
    private array $storages = [];

    public function add(array $data, StorageType $type): void
    {
        if (isset($this->storages[$type->value])) {
            throw new StoragesException('You cannot attach two files of the same type!');
        }
        $this->storages[$type->value] = new Storage(data: $data, storageType: $type, isMany: false);
    }

    public function addMany(array $data, StorageType $type): void
    {
        if (!isset($this->storages[$type->value])) {
            $this->storages[$type->value] = [];
        }

        foreach ($data as $storageData) {
            $this->storages[$type->value][] = new Storage(data: $storageData, storageType: $type, isMany: true);
        }
    }

    public function toArray(): array
    {
        return $this->storages;
    }

    public function getAllStorageIds(): array
    {
        $ids = [];
        foreach ($this->storages as $storage) {
            /** @var Storage $storage */
            if (!is_array($storage)) {
                if ($storage->isFile() && !$storage->isDelete()) {
                    $ids[] = $storage->getFile()->getId();
                }
                continue;
            }
            foreach ($storage as $storageOne) {
                /** @var Storage $storageOne */
                if ($storageOne->isFile() && !$storageOne->isDelete()) {
                    $ids[] = $storageOne->getFile()->getId();
                }
            }
        }

        return $ids;
    }

    public function getAllStorages(): array
    {
        $storages = [];
        foreach ($this->storages as $storage) {
            if (!is_array($storage)) {
                $storages[] = $storage;
                continue;
            }
            foreach ($storage as $storageOne) {
                $storages[] = $storageOne;
            }
        }

        return $storages;
    }
}
