<?php declare(strict_types=1);

namespace App\Enums;

use App\Contracts\StorageType\Audio;
use App\Contracts\StorageType\Image;
use App\Contracts\StorageType\Video;

enum StorageType: int implements Image, Video, Audio
{
    case Logo = 1;
    case ContentImages = 2;

    public function getTitle(): string
    {
        return match ($this) {
            self::Logo => __('validation.attributes.logo'),
            self::ContentImages => __('validation.attributes.content_images'),
        };
    }

    public function getAcceptMimes(): array
    {
        return match ($this) {
            self::Logo          => ['jpeg', 'jpg', 'png'],
            self::ContentImages => ['jpeg', 'jpg', 'png'],
        };
    }

    public function isImage(): bool
    {
        return match ($this) {
            self::Logo          => true,
            self::ContentImages => true,
            default => false
        };
    }

    public function isVideo(): bool
    {
        return match ($this) {
            default => false
        };
    }

    public function isAudio(): bool
    {
        return match ($this) {
            default => false
        };
    }

    public function getFolderName(): string
    {
        return $this->name;
    }
}
