<?php declare(strict_types = 1);

namespace App\Http\Controllers\Admin;

use App\Http\Requests\Admin\Languages\NewLanguageRequest;
use App\Http\Resources\Admin\Languages\NewLanguage;
use App\Services\Admin\LanguageService;
use Illuminate\Http\JsonResponse;

final class LanguagesController extends Controller
{
    public function __construct(
        private readonly LanguageService $languageService,
    ) { }

    public function newLanguage(NewLanguageRequest $request): JsonResponse
    {
        $result = $this->languageService->newLanguage($request->getDto());
        if ($result->isError()) {
            return response()->json($result->getData())->setStatusCode($result->getCode());
        }

        return response()->json(new NewLanguage($result));
    }
}
