<?php declare(strict_types=1);

namespace App\Http\Controllers\Admin\Projects;

use App\Http\Controllers\Admin\Controller;
use App\Http\Requests\Admin\Projects\About\StoreUpdateRequest;
use App\Services\Admin\Project\AboutService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

final class AboutController extends Controller
{
    public function __construct(
        private readonly AboutService $aboutService,
    ) { }

    public function languages(int $project, Request $request): View
    {
        $user = $request->user();
        $result = $this->aboutService->languages($project, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/projects/about/languages', $result->getData());
    }

    public function edit(int $project, int $language, Request $request): View
    {
        $user = $request->user();
        $result = $this->aboutService->edit($project, $language, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/projects/about/edit', $result->getData());
    }

    public function update(int $project, int $language, StoreUpdateRequest $request): RedirectResponse
    {
        $data = $request->getDto();
        $user = $request->user();
        $result = $this->aboutService->storeOrUpdate($project, $language, $data, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.projects.about.edit', [
            'project' => $project,
            'language' => $language,
        ])->withSuccess($result->getMessage());
    }
}
