<?php declare(strict_types=1);

namespace App\Http\Controllers\Admin\Projects;

use App\Dto\QuerySettingsDto;
use App\Http\Controllers\Admin\Controller;
use App\Http\Requests\Admin\Projects\Feedbacks\IndexRequest;
use App\Services\Admin\Project\FeedbackService;
use Illuminate\View\View;

final class FeedbacksController extends Controller
{
    public function __construct(
        private readonly FeedbackService $feedbackService,
    ) { }

    public function index(IndexRequest $request): View
    {
        $user = $request->user();
        $data = $request->getDto();
        $querySettingsDto = new QuerySettingsDto(
            limit: 20,
            page: $data->getPage(),
            queryWith: ['project']
        );

        $result = $this->feedbackService->index($data->getProjectFeedbackBuilderDto(), $querySettingsDto, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin.projects.feedbacks.index', $result->getData());
    }

    public function project(int $projectId, IndexRequest $request): View
    {
        $user = $request->user();
        $data = $request->getDto();
        $querySettingsDto = new QuerySettingsDto(
            limit: 20,
            page: $data->getPage(),
            queryWith: []
        );

        $result = $this->feedbackService->project($projectId, $data->getProjectFeedbackBuilderDto(), $querySettingsDto, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin.projects.feedbacks.project', $result->getData());
    }
}
