<?php declare(strict_types=1);

namespace App\Http\Controllers\Admin\Projects;

use App\Http\Controllers\Admin\Controller;
use App\Http\Requests\Admin\Projects\ServiceTranslate\UpdateRequest;
use App\Services\Admin\Project\ServiceTranslateService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

final class ServiceTranslateController extends Controller
{
    public function __construct(
        private readonly ServiceTranslateService $serviceTranslateService,
    ) { }

    public function view(int $projectId, Request $request): View
    {
        $user = $request->user();
        $result = $this->serviceTranslateService->view($projectId, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin.projects.service-translate.view', $result->getData());
    }

    public function update(int $projectId, UpdateRequest $request): RedirectResponse
    {
        $data = $request->getDto();
        $user = $request->user();
        $result = $this->serviceTranslateService->update($projectId, $data, $user);

        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.projects.service-translate.view', ['project' => $projectId])->withSuccess($result->getMessage());
    }
}
