<?php declare(strict_types=1);

namespace App\Http\Controllers\Admin\Projects;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\Projects\Translations\UpdateRequest;
use App\Services\Admin\Project\TranslationService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

final class TranslationsController extends Controller
{
    public function __construct(
        private readonly TranslationService $translationService,
    ) { }

    public function languages(int $projectId, Request $request): View
    {
        $user = $request->user();
        $result = $this->translationService->languages($projectId, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/projects/translations/languages', $result->getData());
    }

    public function edit(int $projectId, int $languageId, Request $request): View
    {
        $user = $request->user();
        $result = $this->translationService->edit($projectId, $languageId, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/projects/translations/edit', $result->getData());
    }

    public function update(int $projectId, int $languageId, UpdateRequest $request): RedirectResponse
    {
        $user = $request->user();
        $data = $request->getDto();
        $result = $this->translationService->update($projectId, $languageId, $data, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.projects.translations.edit', [
            'project' => $projectId,
            'language' => $languageId,
        ])->withSuccess($result->getMessage());
    }
}
