<?php declare(strict_types=1);

namespace App\Http\Controllers\Admin;

use App\Dto\QuerySettingsDto;
use App\Http\Requests\Admin\Roles\IndexRequest;
use App\Http\Requests\Admin\Roles\StoreUpdateRequest;
use App\Services\Admin\RoleService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

final class RolesController extends Controller
{
    public function __construct(
        private readonly RoleService $roleService
    ) { }
    public function index(IndexRequest $request): View
    {
        $user = $request->user();
        $data = $request->getDto();
        $querySettingsDto = new QuerySettingsDto(
            limit: 20,
            page: $data->getPage(),
            queryWith: ['morph']
        );

        $result = $this->roleService->index($data->getRoleBuilderDto(), $querySettingsDto, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/roles/index', $result->getData());
    }

    public function create(Request $request): View
    {
        $user = $request->user();
        $result = $this->roleService->create($user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/roles/create', $result->getData());
    }

    public function edit(int $id, Request $request): View
    {
        $user = $request->user();
        $result = $this->roleService->edit($id, $user);
        if ($result->isError()) {
            $this->errors($result);
        }

        return view('admin/roles/edit', $result->getData());
    }

    public function store(StoreUpdateRequest $request): RedirectResponse
    {
        $data = $request->getDto();
        $user = $request->user();
        $result = $this->roleService->store($data, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.roles.edit', $result->getModel())->withSuccess($result->getMessage());
    }

    public function update(int $id, StoreUpdateRequest $request): RedirectResponse
    {
        $data = $request->getDto();
        $user = $request->user();
        $result = $this->roleService->update($id, $data, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.roles.edit', $result->getModel())->withSuccess($result->getMessage());
    }

    public function destroy(int $id, Request $request): RedirectResponse
    {
        $user = $request->user();
        $result = $this->roleService->destroy($id, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        return redirect()->route('admin.roles.index')->withSuccess($result->getMessage());
    }
}
