<?php declare(strict_types=1);

namespace App\Http\Controllers\Site;

use App\Http\Requests\Site\Feedback\SendRequest;
use App\Services\Site\FeedbackService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

final class FeedbackController extends Controller
{
    public function __construct(
        private readonly FeedbackService $feedbackService,
    ) { }

    public function index(Request $request): View
    {
        return view('site.feedback.index', [
            'project'             => $request->get('project'),
            'websiteTranslations' => $request->get('websiteTranslations'),
            'captcha'             => config('app.captcha', false),
        ]);
    }

    public function send(SendRequest $request): RedirectResponse
    {
        $project = $request->get('project');
        $websiteTranslations = $request->get('websiteTranslations');
        $user = $request->user();
        $data = $request->getDto();

        $result = $this->feedbackService->send($data, $project, $websiteTranslations, $user);
        if ($result->isError()) {
            return redirect()->back()->withInput()->withErrors($result->getErrorsOrMessage());
        }

        $url = \App\Enums\Site\ProjectSection::Feedback->url($project, $websiteTranslations->getLanguage());
        return redirect($url)->withSuccess($result->getMessage());
    }
}
