<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\About;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\About\StoreUpdate;
use App\Dto\Service\Storage\Storages;
use App\Enums\StorageType;
use Illuminate\Foundation\Http\FormRequest;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    public function attributes(): array
    {
        return [
            'storage.content_images.*.file' => __('validation.attributes.content_images'),
        ];
    }

    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'title' => ['required', 'string', 'max:255',],
            'description' => ['nullable', 'string',],
            'storage.content_images.*.file' => ['numeric', 'min:1'],
            'translate-automatically' => ['nullable', 'boolean'],
        ];
    }

    public function getDto(): StoreUpdate
    {
        return new StoreUpdate(
            title: $this->input('title'),
            description: $this->input('description'),
            storages: $this->storages(),
            isTranslateAutomatically: (bool) $this->input('translate-automatically', false),
        );
    }

    private function storages(): Storages
    {
        $storages = new Storages();

        $content = $this->input('storage', []);
        $images = $content['content_images'] ?? [];
        $storages->addMany($images, StorageType::ContentImages);

        return $storages;
    }
}
