<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\DocumentVersions;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\DocumentationVersion\StoreUpdate;
use App\Enums\DocumentationVersionStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\Enum;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'title' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:70', 'regex:/^[a-z0-9._-]+$/'],
            'is_public' => ['required', 'boolean'],
            'status' => ['required', new Enum(DocumentationVersionStatus::class)],
        ];
    }

    public function getDto(): StoreUpdate
    {
        return new StoreUpdate(
            title: $this->input('title'),
            slug: $this->input('slug'),
            isPublic: (bool) $this->input('is_public', false),
            status: DocumentationVersionStatus::from((int) $this->input('status')),
        );
    }
}
