<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\DocumentationCategories;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\DocumentationCategory\StoreUpdate;
use App\Dto\Service\Admin\Project\DocumentationCategoryContent\Content;
use App\Dto\Service\Admin\Project\DocumentationCategoryContent\Contents;
use Illuminate\Foundation\Http\FormRequest;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'slug' => ['required', 'string', 'max:200', 'regex:/^[a-z0-9._-]+$/'],
            'is_public' => ['required', 'boolean'],
            'sort' => ['required', 'integer', 'min:-1000', 'max:1000'],
            'parent_id' => ['nullable', 'integer', 'exists:documentation_categories,id'],
            'content.*.title' => ['required', 'string', 'max:255'],
            'translate-automatically.*' => ['nullable', 'boolean'],
        ];
    }

    public function getDto(): StoreUpdate
    {
        $parentId = $this->input('parent_id', null);
        if (!\is_null($parentId)) {
            $parentId = (int) $parentId;
        }

        return new StoreUpdate(
            slug: $this->input('slug'),
            isPublic: (bool) $this->input('is_public', false),
            sort: (int) $this->input('sort'),
            contents: $this->getContents(),
            parentId: $parentId,
        );
    }

    private function getContents(): Contents
    {
        $contents = new Contents();
        foreach ($this->input('content', []) as $languageId => $content) {
            $contents->addContent(new Content(
                languageId: (int) $languageId,
                title:      $content['title'],
                isTranslateAutomatically: (bool) $this->input('translate-automatically.' . $languageId, false),
            ));
        }
        return $contents;
    }
}
