<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\Links;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\Link\StoreUpdate;
use Illuminate\Foundation\Http\FormRequest;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'title' => ['required', 'string', 'max:255'],
            'link' => ['required', 'string', 'max:255', 'url:http,https'],
            'sort' => ['required', 'integer', 'min:-1000', 'max:1000'],
            'language_id' => ['nullable', 'integer', 'min:1'],
        ];
    }

    public function getDto(): StoreUpdate
    {
        $languageId = $this->input('language_id');
        if (! \is_null($languageId)) {
            $languageId = (int) $languageId;
        }

        return new StoreUpdate(
            title: $this->input('title'),
            link: $this->input('link'),
            sort: (int) $this->input('sort'),
            languageId: $languageId,
        );
    }
}
