<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\ServiceTranslate;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\ServiceTranslate\Translation;
use App\Dto\Service\Admin\Project\ServiceTranslate\Translations;
use App\Dto\Service\Admin\Project\ServiceTranslate\Update;
use Illuminate\Foundation\Http\FormRequest;

final class UpdateRequest extends FormRequest implements FormRequestDto
{
    public function attributes(): array
    {
        return [
            'language.*.id' => __('validation.attributes.language_id'),
            'language.*.code' => __('validation.attributes.code'),
            'language.*.source_language_id' => __('validation.attributes.source_language_id'),
        ];
    }

    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'language.*.id' => ['required', 'numeric', 'min:1'],
            'language.*.code' => ['nullable', 'string', 'min:2', 'max:50'],
            'language.*.source_language_id' => ['nullable', 'numeric', 'min:1', 'different:language.*.id'],
        ];
    }


    public function getDto(): Update
    {
        $translations = new Translations();
        foreach ($this->input('language', []) as $language) {
            $sourceLanguageId = $language['source_language_id'] ?? null;
            if ($sourceLanguageId) {
                $sourceLanguageId = (int) $sourceLanguageId;
            }

            $translation = new Translation(
                languageId:       (int) $language['id'],
                sourceLanguageId: $sourceLanguageId,
                code:             $language['code'] ?? null,
            );
            $translations->add($translation);
        }

        return new Update(
            translations: $translations,
        );
    }
}
