<?php declare(strict_types=1);

namespace App\Http\Requests\Admin\Projects\Translations;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Admin\Project\Translation\Translation;
use App\Dto\Service\Admin\Project\Translation\Translations;
use App\Dto\Service\Admin\Project\Translation\Update;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\In;

final class UpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'translations'   => ['nullable', 'array'],
            'translations.*.code' => ['required', 'string', new In(Translations::getTranslationCodes())],
            'translations.*.text' => ['nullable', 'string', 'max:1000'],
        ];
    }

    public function getDto(): Update
    {
        $translations = new Translations();
        foreach ($this->input('translations', []) as $translation) {
            $translations->addTranslation(
                code: $translation['code'],
                text: $translation['text'] ?? null,
            );
        }

        return new Update($translations);
    }
}
