<?php declare(strict_types=1);

namespace App\Models;

use App\Models\Scopes\SortScope;
use Illuminate\Database\Eloquent\Attributes\ScopedBy;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;
use Staudenmeir\LaravelAdjacencyList\Eloquent\HasRecursiveRelationships;

#[ScopedBy([SortScope::class])]
final class DocumentationCategory extends Model
{
    use HasFactory, SoftDeletes, HasRecursiveRelationships;

    protected $table = 'documentation_categories';

    /**
     * The model's default values for attributes.
     *
     * @var array
     */
    protected $attributes = [
        'sort'      => 100,
        'is_public' => true,
    ];

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'slug',
        'sort',
        'parent_id',
        'is_public',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'is_public' => 'boolean',
        ];
    }

    public function parent(): BelongsTo
    {
        return $this->belongsTo(DocumentationCategory::class, 'parent_id');
    }

    public function contents(): HasMany
    {
        return $this->hasMany(DocumentationCategoryContent::class, 'category_id');
    }

    public function content(): HasOne
    {
        return $this->hasOne(DocumentationCategoryContent::class, 'category_id');
    }

    public function version(): BelongsTo
    {
        return $this->belongsTo(DocumentationVersion::class, 'version_id');
    }
}
