<?php declare(strict_types=1);

namespace App\Models;

use App\Enums\DocumentationVersionStatus;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

final class DocumentationVersion extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'documentation_versions';

    /**
     * The model's default values for attributes.
     *
     * @var array
     */
    protected $attributes = [
        'is_public' => true,
        'status'    => DocumentationVersionStatus::CurrentVersion,
    ];

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'title',
        'slug',
        'is_public',
        'status',
    ];

    /**
     * The "booted" method of the model.
     */
    protected static function booted(): void
    {
        static::addGlobalScope('status', function (Builder $builder) {
            $builder->orderBy('status', 'desc');
        });
    }

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'is_public' => 'boolean',
            'status'    => DocumentationVersionStatus::class,
        ];
    }

    public function project(): BelongsTo
    {
        return $this->belongsTo(Project::class);
    }

    public function documentations(): HasMany
    {
        return $this->hasMany(Documentation::class, 'version_id');
    }

    public function categories(): HasMany
    {
        return $this->hasMany(DocumentationCategory::class, 'version_id');
    }
}
