<?php declare(strict_types=1);

namespace App\Models;

use App\Models\Scopes\SortScope;
use Illuminate\Database\Eloquent\Attributes\ScopedBy;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;

#[ScopedBy([SortScope::class])]
final class ProjectLink extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'project_links';

    /**
     * Indicates if the model should be timestamped.
     *
     * @var bool
     */
    public $timestamps = false;

    /**
     * The model's default values for attributes.
     *
     * @var array
     */
    protected $attributes = [
        'sort' => 100,
    ];

    protected $fillable = [
        'title',
        'link',
        'sort',
        'language_id',
    ];

    public function language(): BelongsTo
    {
        return $this->belongsTo(ProjectLanguage::class);
    }
}
