<?php declare(strict_types=1);

namespace App\Models;

use App\Enums\StorageType;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage as StorageSupport;

class Storage extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'storage';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'data',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'data' => 'array',
            'type' => StorageType::class,
        ];
    }

    protected function dataImages(): Attribute
    {
        return Attribute::make(
            get: fn () => $this->data['images'] ?? [],
        );
    }

    protected function url(): Attribute
    {
        return Attribute::make(
            get: function () {
                if (\is_null($this->file)) {
                    return '';
                }
                return StorageSupport::disk(config('storage.disk'))->url($this->file) . '?time=' . $this->updated_at->getTimestamp();
            },
        );
    }

    protected function path(): Attribute
    {
        return Attribute::make(
            get: function () {
                if (\is_null($this->file)) {
                    return '';
                }
                return StorageSupport::disk(config('storage.disk'))->path($this->file);
            },
        );
    }
}
