<?php declare(strict_types=1);

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use App\Enums\Lang;
use App\Enums\SystemRole;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\SoftDeletes;

final class User extends Authenticatable
{
    use HasFactory, Notifiable, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'nickname',
        'timezone',
        'lang',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
            'lang' => Lang::class,
        ];
    }

    public function roles(): belongsToMany
    {
        return $this->belongsToMany(Role::class);
    }

    public function hasPermission(string $permission): bool
    {
        return $this->permissions->search($permission) !== false;
    }

    protected function isAdmin(): Attribute
    {
        return Attribute::make(
            get: fn () => $this->roles
                ->where('code', SystemRole::Admin->value)
                ->whereNull('morphable_type')
                ->whereNull('morphable_id')
                ->isNotEmpty(),
        )->shouldCache();
    }

    protected function permissions(): Attribute
    {
        return Attribute::make(
            get: function () {
                $roles = $this->roles->modelKeys();
                return RolePermission::query()->whereIn('role_id', $roles)->select('permission')->pluck('permission');
            },
        )->shouldCache();
    }
}
