<?php declare(strict_types=1);

namespace App\Repositories;

use App\Contracts\Search;
use App\Models\Project;
use App\Services\ProjectLink\BuilderCommand;
use App\Services\Search\CreateSearchInstanceCommand;
use App\Dto\Builder\ProjectLink as ProjectLinkBuilderDto;
use App\Models\ProjectLink;
use Illuminate\Support\Collection;
use Illuminate\Database\Eloquent\Builder;

final readonly class ProjectLinkRepository
{
    public function __construct(
        private CreateSearchInstanceCommand $createSearchInstanceCommand,
        private BuilderCommand $builderCommand
    ) { }

    public function getLinksFromProject(int $projectId, ProjectLinkBuilderDto $projectLinkBuilderDto, array $with = []): Search
    {
        $query = $this->builderCommand->execute(
            query: ProjectLink::query()->where('project_id', $projectId)->with($with),
            projectLinkBuilderDto: $projectLinkBuilderDto,
        );

        return $this->createSearchInstanceCommand->execute($query);
    }

    public function getLinkById(int $id): ?ProjectLink
    {
        return ProjectLink::query()->where('id', $id)->first();
    }

    public function getLinksByProject(Project $project, int $languageId): Collection
    {
        return $project->links()->where(function (Builder $query) use ($languageId) {
            $query->whereNull('language_id')->orWhere('language_id', $languageId);
        })->get();
    }
}
