<?php declare(strict_types=1);

namespace App\Repositories;

use App\Contracts\Search;
use App\Enums\Morph;
use App\Models\ProjectTranslationServiceHash;
use App\Services\Search\CreateSearchInstanceCommand;
use Illuminate\Database\Eloquent\Builder;

final readonly class ProjectTranslationServiceHashRepository
{
    public function __construct(
        private CreateSearchInstanceCommand $createSearchInstanceCommand,
    ) { }

    public function getHashes(Morph $morph, int $morphId, ?array $languages = null, ?array $fields = null): Search
    {
        $query = ProjectTranslationServiceHash::query()
            ->where('morph_type', $morph)
            ->where('morph_id', $morphId)
            ->when($languages, function (Builder $query) use ($languages) {
                $query->whereIn('language_id', $languages);
            })
            ->when($fields, function (Builder $query) use ($fields) {
                $query->whereIn('field', $fields);
            });

        return $this->createSearchInstanceCommand->execute($query);
    }

    public function getHashesByIds(array $ids): Search
    {
        $query = ProjectTranslationServiceHash::query()->whereIn('id', $ids);
        return $this->createSearchInstanceCommand->execute($query);
    }
}
