<?php declare(strict_types=1);

namespace App\Rules;

use Closure;
use Illuminate\Contracts\Validation\ValidationRule;

final readonly class HttpHost implements ValidationRule
{
    /**
     * Run the validation rule.
     *
     * @param  \Closure(string): \Illuminate\Translation\PotentiallyTranslatedString  $fail
     */
    public function validate(string $attribute, mixed $value, Closure $fail): void
    {
        if (!is_string($value) && !is_array($value)) {
            $fail('validation.no_type')->translate(['type' => 'string, array']);
            return;
        }

        if (is_string($value)) {
            $this->validateHttpHost($value, $fail);
        }

        if (is_array($value)) {
            foreach ($value as $item) {
                $this->validateHttpHost($item, $fail);
            }
        }
    }

    private function validateHttpHost(string $value, Closure $fail): void
    {
        $scheme = explode('://', $value, 2);
        if (count($scheme) != 2 || in_array($scheme[0], ['http', 'https'], true) !== true) {
            $fail('validation.http_host')->translate();
            return;
        }

        $host = explode(':', $scheme[1], 2);
        if (!filter_var($host[0], FILTER_VALIDATE_DOMAIN, FILTER_FLAG_HOSTNAME)) {
            $fail('validation.http_host')->translate();
            return;
        }

        if (isset($host[1]) && (!is_numeric($host[1]) || $host[1] <= 0)) {
            $fail('validation.http_host')->translate();
            return;
        }
    }
}
