<?php declare(strict_types=1);

namespace App\ServiceResults\Storage;

use App\Dto\Service\Storage\Storage as StorageDto;
use App\Models\Storage as StorageModel;
use App\ServiceResults\ServiceResult;

final class SaveDeleteStorageResult extends ServiceResult
{
    private array $storagesForDelete = [];
    private array $storagesForSave = [];

    public function addDelete(StorageDto $storageDto): void
    {
        $type = $storageDto->getStorageType();
        if (!isset($this->storagesForDelete[$type->value])) {
            $this->storagesForDelete[$type->value] = [
                'ids' => [],
                'type' => $type,
                'isDeleteType' => ($storageDto->isMany() !== true),
            ];
        }

        if ($storageDto->isFile()) {
            $id = $storageDto->getFile()->getId();
            $this->storagesForDelete[$type->value]['ids'][] = $id;
        }
    }

    public function addSave(StorageModel $storage, StorageDto $storageDto): void
    {
        $this->storagesForSave[] = [
            'storage' => $storage,
            'isMany' => $storageDto->isMany(),
        ];
    }

    public function getStoragesForDelete(): array
    {
        return $this->storagesForDelete;
    }

    public function getStoragesForSave(): array
    {
        return $this->storagesForSave;
    }
}
