<?php declare(strict_types=1);

namespace App\Services\Admin\Project;

use App\Dto\Builder\ProjectFeedback as ProjectFeedbackBuilderDto;
use App\Dto\QuerySettingsDto;
use App\Models\ProjectFeedback;
use App\Models\User;
use App\Repositories\ProjectFeedbackRepository;
use App\Repositories\ProjectRepository;
use App\ServiceResults\ServiceResultArray;
use App\ServiceResults\ServiceResultError;
use App\Services\Service;

final class FeedbackService extends Service
{
    public function __construct(
        private readonly ProjectFeedbackRepository $projectFeedbackRepository,
        private readonly ProjectRepository $projectRepository,
    ) { }

    public function index(ProjectFeedbackBuilderDto $projectFeedbackBuilderDto, QuerySettingsDto $querySettingsDto, User $user): ServiceResultError | ServiceResultArray
    {
        if ($user->cannot('viewAny', ProjectFeedback::class)) {
            return $this->errFobidden(__('Access is denied'));
        }

        $feedbacks = $this->projectFeedbackRepository->getFeedbacks(
            $projectFeedbackBuilderDto,
            $querySettingsDto->getQueryWith()
        )->pagination(
            $querySettingsDto->getLimit(),
            $querySettingsDto->getPage()
        );

        return $this->result([
            'feedbacks' => $feedbacks,
        ]);
    }

    public function project(int $projectId, ProjectFeedbackBuilderDto $projectFeedbackBuilderDto, QuerySettingsDto $querySettingsDto, User $user): ServiceResultError | ServiceResultArray
    {
        $project = $this->projectRepository->getProjectById($projectId);
        if (\is_null($project)) {
            return $this->errNotFound(__('Not Found'));
        }

        if ($user->cannot('viewAny', ProjectFeedback::class)) {
            return $this->errFobidden(__('Access is denied'));
        }

        $feedbacks = $this->projectFeedbackRepository->getFeedbacksByProject(
            $project,
            $projectFeedbackBuilderDto,
            $querySettingsDto->getQueryWith()
        )->pagination(
            $querySettingsDto->getLimit(),
            $querySettingsDto->getPage()
        );

        return $this->result([
            'project' => $project,
            'feedbacks' => $feedbacks,
        ]);
    }
}
