<?php declare(strict_types=1);

namespace App\Services\DocumentationCategory;

use App\Exceptions\Services\DocumentationCategory\ParentException;
use App\Models\DocumentationCategory;
use App\Models\DocumentationVersion;
use Illuminate\Support\Str;

final readonly class DocumentationCategoryCommandHandler
{
    public function handleStore(DocumentationVersion $version, array $data): DocumentationCategory
    {
        $data['slug'] = Str::lower($data['slug']);
        return $version->categories()->create($data);
    }

    public function handleUpdate(DocumentationCategory $category, array $data): DocumentationCategory
    {
        if (!empty($data['parent_id'])) {
            $category->parent_id = $data['parent_id'];
            if ($category->ancestors()->withTrashed()->where('id', $category->id)->exists()) {
                throw new ParentException('Category ID occurs in the parent chain (category: ' . $category->id . ', parent_id: ' . $category->parent_id . ').');
            }
        }

        if (isset($data['slug'])) {
            $data['slug'] = Str::lower($data['slug']);
        }

        $category->update($data);
        $category->touch();

        return $category;
    }

    public function handleDestroy(DocumentationCategory $category): void
    {
        $category->update([
            'slug' => $category->slug . '#delete:' . $category->id,
        ]);
        $category->delete();
    }
}
