<?php declare(strict_types=1);

namespace App\Services\DocumentationCategoryContent;

use App\Dto\Service\Admin\Project\DocumentationCategoryContent\Content;
use App\Dto\Service\Admin\Project\DocumentationCategoryContent\Contents;
use App\Exceptions\Services\DocumentationCategoryContent\ContentSaveException;
use App\Models\DocumentationCategory;
use App\Models\Project;

final readonly class ModelSyncCommand
{
    public function execute(Project $project, DocumentationCategory $category, Contents $contents): void
    {
        $languages = $project->languages;
        $categoryContents = $category->contents;

        $newContents = [];
        foreach ($contents->getContents() as $content)   {
            /** @var Content $content */
            $language = $languages->firstWhere('id', $content->getLanguageId());
            if (!$language) {
                throw new ContentSaveException('Language not found: ' . $content->getLanguageId());
            }

            $model = $categoryContents->firstWhere('language_id', $language->id);
            $data  = $this->getData($content);
            if (\is_null($model)) {
                $newContents[] = array_merge(['language_id' => $content->getLanguageId()], $data);
                continue;
            }
            $model->update($data);
        }

        if (!empty($newContents)) {
            $category->contents()->createMany($newContents);
        }
    }

    private function getData(Content $content): array
    {
        return [
            'title' => $content->getTitle(),
        ];
    }
}
