<?php declare(strict_types=1);

namespace App\Services\ProjectLanguage;

use App\Dto\Service\Admin\Project\Language;
use App\Dto\Service\Admin\Project\Languages;
use App\Models\Project;
use Illuminate\Database\Eloquent\Collection;

final readonly class ModelSyncCommand
{
    public function execute(Project $project, Languages $languages): void
    {
        $projectLanguages = $project->languages()->get();
        $this->deleteLanguages($languages, $projectLanguages);

        $languagesInsert = [];
        $languagesUpdate = [];
        foreach ($languages->getLanguages() as $language) {
            /** @var Language $language */
            $data = [
                'code' => $language->getCode(),
                'title' => $language->getTitle(),
                'sort' => $language->getSort(),
                'is_default' => $language->isDefault(),
                'system_lang' => $language->getSystemLang(),
                'iso_code' => $language->getIsoCode(),
            ];

            if ($language->getId() !== null) {
                $projectLanguage = $projectLanguages->firstWhere('id', $language->getId());
                if ($projectLanguage !== null) {

                    $projectLanguageFix = $projectLanguages->firstWhere('code', $language->getCode());
                    if ($projectLanguageFix !== null && !in_array($projectLanguageFix->id, $languagesUpdate)) {
                        // Fixing a bug when language codes are swapped.
                        $projectLanguageFix->update([
                           'code' => $projectLanguageFix->code . '-' . $projectLanguageFix->id,
                        ]);
                    }

                    $projectLanguage->update($data);
                    $languagesUpdate[] = $projectLanguage->id;
                    continue;
                }
            }
            $languagesInsert[] = $data;
        }

        if (!empty($languagesInsert)) {
            $project->languages()->createMany($languagesInsert);
        }
    }

    private function deleteLanguages(Languages $languages, Collection $projectLanguages): void
    {
        $languagesIdUpdate = [];
        foreach ($languages->getLanguages() as $language) {
            /** @var Language $language */
            if ($language->getId() === null) {
                continue;
            }
            $languagesIdUpdate[] = $language->getId();
        }

        foreach ($projectLanguages as $projectLanguage) {
            if (in_array($projectLanguage->id, $languagesIdUpdate)) {
                continue;
            }
            $projectLanguage->update([
                'code' => $projectLanguage->code . '-' . $projectLanguage->id,
            ]);
            $projectLanguage->delete();
        }
    }
}
