<?php declare(strict_types=1);

namespace App\Services\ProjectTranslation;

use App\Dto\Service\Admin\Project\Translation\Translation;
use App\Dto\Service\Admin\Project\Translation\Translations;
use App\Models\Project;
use App\Models\ProjectLanguage;
use App\Models\ProjectTranslation;
use App\Repositories\ProjectTranslationRepository;
use Illuminate\Support\Carbon;

final readonly class ModelSyncCommand
{
    public function __construct(
        private ProjectTranslationRepository $projectTranslationRepository,
    ) { }

    public function execute(Project $project, ProjectLanguage $language, Translations $update): void
    {
        $modelTranslations = $this->projectTranslationRepository->getProjectTranslationsWithTrashed($project->id, $language->id)->all();
        $insert = [];
        foreach ($update->getTranslations() as $translation) {
            /** @var Translation $translation */
            /** @var ProjectTranslation $modelTranslation */
            $modelTranslation = $modelTranslations->firstWhere('code', $translation->getCode());

            if ($modelTranslation === null && $translation->getText() === null) {
                continue;
            }

            if ($modelTranslation === null && $translation->getText() !== null) {
                $insert[] = [
                    'created_at'  => Carbon::now(),
                    'updated_at'  => Carbon::now(),
                    'project_id'  => $project->id,
                    'language_id' => $language->id,
                    'code' => $translation->getCode(),
                    'text' => $translation->getText(),
                ];
                continue;
            }

            if ($modelTranslation !== null && $translation->getText() === null) {
                $modelTranslation->delete();
                continue;
            }

            if ($modelTranslation->trashed()) {
                $modelTranslation->deleted_at = null;
            }
            $modelTranslation->text = $translation->getText();
            $modelTranslation->save();
        }

        if (!empty($insert)) {
            ProjectTranslation::query()->insert($insert);
        }
    }
}
