<?php declare(strict_types=1);

namespace App\Services\Site;

use App\Models\Project;
use App\Models\User;
use App\Dto\Builder\Project as ProjectBuilderDto;
use App\Repositories\ProjectContentRepository;
use App\Repositories\ProjectLinkRepository;
use App\Repositories\ProjectRepository;
use App\ServiceResults\ServiceResultArray;
use App\ServiceResults\ServiceResultError;
use App\ServiceResults\Site\PagePossibleWithoutTranslation;
use App\Services\Service;
use App\Services\WebsiteTranslations;

final class ProjectService extends Service
{
    public function __construct(
        private readonly ProjectRepository $projectRepository,
        private readonly ProjectContentRepository $projectContentRepository,
        private readonly ProjectLinkRepository $projectLinkRepository,
    ) { }

    public function getProjects(?User $user, array $with): ServiceResultError | ServiceResultArray
    {
        $isPublic = null;
        if (\is_null($user) || $user->cannot('viewAny', Project::class)) {
            $isPublic = true;
        }
        $projectBuilderDto = new ProjectBuilderDto(
            isPublic: $isPublic,
        );
        $projects = $this->projectRepository->getProjects($projectBuilderDto, $with);

        return $this->result([
            'projects' => $projects->all(),
        ]);
    }

    public function getAboutByProject(Project $project, WebsiteTranslations $websiteTranslations, ?User $user = null): ServiceResultError | PagePossibleWithoutTranslation
    {
        if (
            $project->is_public === false
            && ( $user === null || $user->cannot('view', $project) )
        ) {
            return $this->errFobidden(__('Access is denied'));
        }

        $data = [
            'project'  => $project,
            'websiteTranslations' => $websiteTranslations,
            'content'  => $this->projectContentRepository->getContentByLanguageId($project->id, $websiteTranslations->getLanguage()->id),
            'links'    => $this->projectLinkRepository->getLinksByProject($project, $websiteTranslations->getLanguage()->id),
        ];
        return $this->resultSitePage($project, $websiteTranslations, $data, \is_null($data['content']));
    }
}
