<?php declare(strict_types=1);

namespace App\Services\Storage\Image;

use App\Models\Storage;
use Intervention\Image\Laravel\Facades\Image as InterventionImage;

final readonly class ResizeCommandHandler
{
    public function resize(Storage $storage, int $width, int $height): Storage
    {
        $image = InterventionImage::read($storage->path);
        if ($image->width() < $width && $image->height() < $height) {
            return $storage;
        }

        $image->scale($width, $height)
            ->save($storage->path);

        $storage->touch();
        return $storage;
    }

    public function width(Storage $storage, int $width): Storage
    {
        $image = InterventionImage::read($storage->path);
        if ($image->width() < $width) {
            return $storage;
        }

        $image->scale(width: $width)
            ->save($storage->path);

        $storage->touch();
        return $storage;
    }

    public function height(Storage $storage, int $height): Storage
    {
        $image = InterventionImage::read($storage->path);
        if ($image->height() < $height) {
            return $storage;
        }

        $image->scale(height: $height)
            ->save($storage->path);

        $storage->touch();
        return $storage;
    }
}
