<?php declare(strict_types=1);

namespace App\Services\Storage;

use App\Dto\Service\Storage\Upload;
use App\Enums\StorageType;
use app\Exceptions\Services\Storage\StorageCommandHandlerException;
use App\Exceptions\Services\Storage\StorageSaveFileException;
use App\Models\Storage;
use App\Models\User;
use App\Contracts\Models\Storage as ModelStorageContract;
use Illuminate\Support\Str;

final readonly class StorageCommandHandler
{
    public function __construct(
        private string $disc,
    ) { }

    public function handleStore(Upload $upload, User $user, array $data = []): Storage
    {
        $folder = '/' . $upload->getMorph()->getFolderName();
        $folder .= date("/Y/m/d");
        $folder .= '/' . $upload->getStorageType()->getFolderName();
        $folder = Str::lower($folder);
        $path = $upload->getFile()->store($folder, $this->disc);

        if ($path === false) {
            throw new StorageSaveFileException('Could not save the file: ' . $upload->getFile()->getFilename() . '.');
        }

        $storage = new Storage();
        $storage->created_user_id = $user->id;
        $storage->file = '/' . $path;
        $storage->type = $upload->getStorageType();
        $storage->morph_type = $upload->getMorph()->value;

        if (!empty($data)) {
            $storage->fill($data);
        }
        $storage->save();

        return $storage;
    }

    public function handleStorageAttachModel(Storage $storage, ModelStorageContract $model): Storage
    {
        if ($storage->morph_id === $model->id) {
            return $storage;
        }

        if (!\is_null($storage->morph_id)) {
            throw new StorageCommandHandlerException('The model is already attached!');
        }

        $storage->morph_id = $model->id;
        $storage->save();

        return $storage;
    }

    public function handleUpdate(Storage $storage, array $data = []): Storage
    {
        $storage->update($data);
        return $storage;
    }

    public function handleDestroy(Storage $storage): void
    {
        $storage->delete();
    }

    public function handleDestroyByIds(array $ids): void
    {
        if (!empty($ids)) {
            Storage::whereIn('id', $ids)->delete();
        }
    }

    public function handleDestroyByModel(ModelStorageContract $model, StorageType $type): void
    {
        $model->storage()->where('type', $type)->delete();
    }

    public function handleDestroyByModelStorageIds(ModelStorageContract $model, array $ids, StorageType $type): void
    {
        if (!empty($ids)) {
            $model->storage()->whereIn('id', $ids)->where('type', $type)->delete();
        }
    }
}
