<?php declare(strict_types=1);

namespace app\Services\Storage;

use App\Enums\Morph;
use App\Enums\StorageType;
use App\Models\Storage as StorageModel;
use App\ServiceResults\ServiceResultError;
use App\ServiceResults\ServiceResultSuccess;
use App\Services\Service;

final class ValidationService extends Service
{
    public function execute(StorageModel $storageModel, Morph $morph, StorageType $storageType, ?int $modelId = null): ServiceResultError | ServiceResultSuccess
    {
        if (! $this->isMorphMatched($storageModel, $morph, $modelId)) {
            return $this->errValidate(__('storage.Attempt to replace a file'));
        }

        if (! $this->isTypeMatched($storageModel, $storageType)) {
            return $this->errValidate(__('storage.Wrong file type'));
        }

        return $this->ok(__('OK'));
    }

    private function isMorphMatched(StorageModel $storageModel, Morph $morph, ?int $modelId = null): bool
    {
        if ($storageModel->morph_type !== $morph->value) {
            return false;
        }

        if (!\is_null($storageModel->morph_id) && $storageModel->morph_id !== $modelId) {
            return false;
        }

        return true;
    }

    private function isTypeMatched(StorageModel $storageModel, StorageType $type): bool
    {
        if ($storageModel->type !== $type) {
            return false;
        }

        return true;
    }
}
