<?php declare(strict_types=1);

namespace App\View\Components\Volt\Forms;

use Illuminate\View\View;

final class Languages extends Form
{
    public function __construct(
        private readonly string $name,
        private readonly array $value,
    ) { }

    protected function getName(): string
    {
        return $this->name;
    }

    private function getValue(): array
    {
        $value = old($this->getRequestName(), null);
        if (\is_null($value) || !isset($value['items']) || !\is_array($value['items'])) {
            return $this->value;
        }

        $langs = [];
        $default = $value['default'] ?? null;
        if ($default !== null) {
            $default = (int) $default;
        }
        foreach ($value['items'] as $index => $lang) {
            $systemLang = null;
            if (!empty($lang['system_lang'])) {
                $systemLang = (int) $lang['system_lang'];
            }
            $langs[$index] = [
                'title'       => $lang['title'] ?? '',
                'code'        => $lang['code'] ?? '',
                'is_default'  => ($index === $default),
                'sort'        => $lang['sort'] ?? '',
                'system_lang' => $systemLang,
                'iso_code'    => $lang['iso_code'] ?? null,
                'id'          => $lang['id'] ?? null,
            ];
        }

        return $langs;
    }

    /**
     * @inheritDoc
     */
    public function render(): View
    {
        return view('components.volt.forms.languages', [
            'name' => $this->getName(),
            'value' => $this->getValue(),
        ]);
    }
}
