<?php declare(strict_types=1);

namespace App\View\Components\Volt\Forms;

use Illuminate\Support\Str;
use Illuminate\View\View;

final class MultiCheckbox extends Form
{
    /**
     * @param string $title
     * @param string $name
     * @param array $list = [ [key => value], ... ]
     * @param array $value
     */
    public function __construct(
        private readonly string $title,
        private readonly string $name,
        private readonly array $list,
        private readonly array $value = []
    ) { }

    protected function getName(): string
    {
        return $this->name;
    }

    private function getTitle(): string
    {
        return Str::ucfirst($this->title);
    }

    private function getValue(): array
    {
        return old($this->getRequestName(), $this->value);
    }

    private function getList(): array
    {
        return $this->list;
    }

    public function render(): View
    {
        return view('components.volt.forms.multi_checkbox', [
            'title' => $this->getTitle(),
            'name' => $this->getName(),
            'requestName' => $this->getRequestName(),
            'list' => $this->getList(),
            'value' => $this->getValue()
        ]);
    }
}
