<?php declare(strict_types=1);

namespace App\View\Components\Volt\Forms\Upload;

use App\Enums\Morph;
use App\Models\Storage;
use App\Repositories\StorageRepository;
use App\View\Components\Volt\Forms\Form;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;
use Illuminate\View\View;
use App\Contracts\StorageType\Image as ImageContract;

final class Image extends Form
{
    public function __construct(
        private readonly string $title,
        private readonly string $name,
        private readonly Morph $morph,
        private readonly ImageContract $storageType,
        private readonly StorageRepository $storageRepository,
        private readonly ?Storage $storage = null,
    ) { }

    protected function getName(): string
    {
        return $this->name;
    }

    private function getTitle(): string
    {
        return Str::ucfirst($this->title);
    }

    private function getMorph(): Morph
    {
        return $this->morph;
    }

    private function getStorageType(): ImageContract
    {
        return $this->storageType;
    }

    private function getAcceptedFiles(): Collection
    {
        return collect($this->getStorageType()->getAcceptMimes());
    }

    private function getStorage(): ?Storage
    {
        $name = $this->getRequestName();
        $storageId = old($name . '.file');
        if (!empty($storageId)) {
            return $this->storageRepository->getStorageById((int) $storageId);
        }

        return $this->storage;
    }

    /**
     * @inheritDoc
     */
    public function render(): View
    {
        return view('components.volt.forms.upload.image', [
            'storage'       => $this->getStorage(),
            'title'         => $this->getTitle(),
            'name'          => $this->getName(),
            'morph'         => $this->getMorph(),
            'storageType'   => $this->getStorageType(),
            'acceptedFiles' => $this->getAcceptedFiles(),
        ]);
    }
}
