@section('meta_title', __('admin-sections.Categories'))
@section('h1')
    {{ __('admin-sections.Project') . ': ' . $project->name . ' (' . $version->title . ')' }}
@endsection
<x-admin.layout>
    @include('admin.projects.documentation-categories._top')
    <div class="card border-0 shadow mb-4">
        <div class="card-body">
            <h3 id="category" class="mb-4">{{ __('admin-sections.Categories') }}</h3>
            <div class="table-responsive">
                <table class="table table-centered table-nowrap mb-0 rounded">
                    <thead class="thead-light">
                    <tr>
                        <th class="border-0">{{ __('validation.attributes.title') }}</th>
                        <th class="border-0">{{ __('validation.attributes.slug') }}</th>
                        <th class="border-0">{{ __('validation.attributes.is_public') }}</th>
                        <th class="border-0 rounded-end" style="width: 150px"></th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($categories as $category)
                        <tr>
                            <td>
                                {{ $category->content?->title }}
                            </td>
                            <td>
                                {{ $category->slug }}
                            </td>
                            <td>
                                @if($category->is_public)
                                    {{ __('Yes') }}
                                @else
                                    {{ __('No') }}
                                @endif
                            </td>
                            <td>
                                <a href="{{ route('admin.projects.documentation-versions.categories.edit', ['project' => $project->id, 'version' => $version->id, 'category' => $category->id]) }}" class="btn btn-primary" data-bs-toggle="tooltip" data-bs-placement="top" title="{{ __('Edit') }}">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="align-text-top" viewBox="0 0 16 16">
                                        <path d="M12.854.146a.5.5 0 0 0-.707 0L10.5 1.793 14.207 5.5l1.647-1.646a.5.5 0 0 0 0-.708l-3-3zm.646 6.061L9.793 2.5 3.293 9H3.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.207l6.5-6.5zm-7.468 7.468A.5.5 0 0 1 6 13.5V13h-.5a.5.5 0 0 1-.5-.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.5-.5V10h-.5a.499.499 0 0 1-.175-.032l-.179.178a.5.5 0 0 0-.11.168l-2 5a.5.5 0 0 0 .65.65l5-2a.5.5 0 0 0 .168-.11l.178-.178z"/>
                                    </svg>
                                </a>
                                @can('delete', $category)
                                    <form method="post" class="d-inline-block" action="{{ route('admin.projects.documentation-versions.categories.destroy', ['project' => $project->id, 'version' => $version->id, 'category' => $category->id]) }}">
                                        @csrf
                                        @method('DELETE')
                                        <button type="submit" class="btn btn-danger click-confirm" data-bs-toggle="tooltip" data-bs-placement="top" title="{{ __('Delete') }}">
                                            <svg data-slot="icon" fill="currentColor" width="20" height="20" class="align-text-center" stroke-width="1.5" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" aria-hidden="true">
                                                <path stroke-linecap="round" stroke-linejoin="round" d="M6 18 18 6M6 6l12 12"></path>
                                            </svg>
                                        </button>
                                    </form>
                                @endcan
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                <div class="card-footer border-0">
                    {{ $categories->links() }}
                </div>
            </div>
        </div>
    </div>
    @push('scripts')
        @include('admin._scripts._click-confirm', ['alert' => __('Do you want to delete?')])
    @endpush
</x-admin.layout>
