<hr>
<div class="mb-4">
    <label>{{ __('Languages') }}</label>
    <div class="table-responsive">
        <table class="table table-centered table-nowrap mb-0 rounded table-languages">
            <thead class="thead-light">
                <tr>
                    <th class="border-0 rounded-start">{{ __('validation.attributes.title') }}</th>
                    <th class="border-0" style="width: 200px;">{{ __('validation.attributes.code') }}</th>
                    <th class="border-0" style="width: 140px;">{{ __('validation.attributes.sort') }}</th>
                    <th class="border-0" style="width: 120px;">{{ __('validation.attributes.iso_code') }}</th>
                    <th class="border-0">{{ __('validation.attributes.system_lang') }}</th>
                    <th class="border-0">{{ __('validation.attributes.is_default') }}</th>
                    <th class="border-0 rounded-end"></th>
                </tr>
            </thead>
            <tbody>
                @foreach($value as $index => $lang)
                    <tr class="item-language">
                        @include('components.volt.forms.languages.language', ['index' => $index, 'name' => $name, 'lang' => $lang])
                    </tr>
                @endforeach
            </tbody>
            <tfoot>
                <tr>
                    <td colspan="5">
                        <input type="hidden" class="language-number" name="{{ $name . '[language-number]' }}" value="{{ old($name . '.language-number', count($value)) }}">
                        <button class="btn btn-outline-primary add-language" type="button">+ {{ __('Add language') }}</button>
                    </td>
                </tr>
            </tfoot>
        </table>
    </div>
</div>
@pushOnce('scripts')
    <script>
        (function() {
            function languagesEventListener(tableLanguage) {
                let languageIndex = tableLanguage.querySelector('input.language-number'),
                    addBlock = tableLanguage.querySelector('tbody');
                tableLanguage.querySelector('button.add-language').addEventListener('click', (e) => {
                    ++languageIndex.value;
                    axios.post('{{ route('admin.new-language') }}', {
                        _token: document.querySelector('meta[name="csrf-token"]').getAttribute('content'),
                        name: '{{ $name }}',
                        index: Number(languageIndex.value),
                    })
                    .then(response => {
                        let container = document.createElement("tr");
                        container.classList = 'item-language';
                        container.innerHTML = response.data.html;
                        let button = container.querySelector('button.delete');
                        addEventButtonDelete(button, tableLanguage);
                        addBlock.append(container);
                        languagesHideShowButtonDelete(tableLanguage);
                    })
                    .catch(error => {
                        let container = document.createElement("div");
                        container.classList = 'alert alert-danger';
                        container.setAttribute('role', 'alert');
                        container.innerHTML = `{{ __('There was an error adding a language') }}<button type="button" class="btn-close alert__close" data-bs-dismiss="alert"></button>`;
                        e.target.after(container);
                    });
                });
                languagesHideShowButtonDelete(tableLanguage, tableLanguage);
                let buttonsDelete = tableLanguage.querySelectorAll('button.delete');
                if (buttonsDelete.length > 0) {
                    buttonsDelete.forEach(addEventButtonDelete, tableLanguage);
                }
            }

            function addEventButtonDelete(button, tableLanguage) {
                button.addEventListener('click', (e) => {
                    e.target.parentElement.parentElement.remove();
                    languagesHideShowButtonDelete(tableLanguage);
                });
            }

            function languagesHideShowButtonDelete(tableLanguage) {
                let buttons = tableLanguage.querySelectorAll('button.delete'),
                    display = 'inline-block';
                if (buttons.length === 1) {
                    display = 'none';
                }
                buttons.forEach(function (button) {
                    button.style.display = display;
                });
            }

            let languages = document.querySelectorAll('.table-languages');
            if (languages.length > 0) {
                languages.forEach(languagesEventListener);
            }
        })();
    </script>
@endPushOnce
